@@ -1,9 +1,7 @@
-import os, inspect, sys
-
-from PyQt5.QtGui import QPainter
-from PyQt5.QtSvg import QSvgRenderer
-from PyQt5.QtWidgets import QLabel
-from python_get_absolute_resource_path.getAbsoulteResourcePath import get_absolute_resource_path
+from qtpy.QtGui import QPainter
+from qtpy.QtSvg import QSvgRenderer
+from qtpy.QtWidgets import QLabel
+import absresgetter
 
 
 class SvgLabel(QLabel):
@@ -19,6 +17,6 @@ class SvgLabel(QLabel):
         return super().paintEvent(e)
 
     def setSvgFile(self, filename: str):
-        filename = get_absolute_resource_path(filename)
+        filename = absresgetter.getabsres(filename)
         self.__renderer = QSvgRenderer(filename)
         self.resize(self.__renderer.defaultSize())
\ No newline at end of file
